# pulpcore_client

PulpcoreClient - the Ruby gem for the Pulp 3 API

Fetch, Upload, Organize, and Distribute Software Packages

This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v3
- Package version: 3.16.0
- Build package: org.openapitools.codegen.languages.RubyClientCodegen
For more information, please visit [https://pulpproject.org](https://pulpproject.org)

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build pulpcore_client.gemspec
```

Then either install the gem locally:

```shell
gem install ./pulpcore_client-3.16.0.gem
```

(for development, run `gem install --dev ./pulpcore_client-3.16.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'pulpcore_client', '~> 3.16.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'pulpcore_client', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:

```ruby
# Load the gem
require 'pulpcore_client'

# Setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR_USERNAME'
  config.password = 'YOUR_PASSWORD'
end

api_instance = PulpcoreClient::AccessPoliciesApi.new
opts = {
  customized: true, # Boolean | 
  limit: 56, # Integer | Number of results to return per page.
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  viewset_name: 'viewset_name_example', # String | Filter results where viewset_name matches value
  viewset_name__contains: 'viewset_name__contains_example', # String | Filter results where viewset_name contains value
  viewset_name__icontains: 'viewset_name__icontains_example', # String | Filter results where viewset_name contains value
  viewset_name__in: ['viewset_name__in_example'], # Array<String> | Filter results where viewset_name is in a comma-separated list of values
  viewset_name__startswith: 'viewset_name__startswith_example', # String | Filter results where viewset_name starts with value
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List access policys
  result = api_instance.list(opts)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling AccessPoliciesApi->list: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://pulp*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*PulpcoreClient::AccessPoliciesApi* | [**list**](docs/AccessPoliciesApi.md#list) | **GET** /pulp/api/v3/access_policies/ | List access policys
*PulpcoreClient::AccessPoliciesApi* | [**partial_update**](docs/AccessPoliciesApi.md#partial_update) | **PATCH** {access_policy_href} | Update an access policy
*PulpcoreClient::AccessPoliciesApi* | [**read**](docs/AccessPoliciesApi.md#read) | **GET** {access_policy_href} | Inspect an access policy
*PulpcoreClient::AccessPoliciesApi* | [**update**](docs/AccessPoliciesApi.md#update) | **PUT** {access_policy_href} | Update an access policy
*PulpcoreClient::ArtifactsApi* | [**create**](docs/ArtifactsApi.md#create) | **POST** /pulp/api/v3/artifacts/ | Create an artifact
*PulpcoreClient::ArtifactsApi* | [**delete**](docs/ArtifactsApi.md#delete) | **DELETE** {artifact_href} | Delete an artifact
*PulpcoreClient::ArtifactsApi* | [**list**](docs/ArtifactsApi.md#list) | **GET** /pulp/api/v3/artifacts/ | List artifacts
*PulpcoreClient::ArtifactsApi* | [**read**](docs/ArtifactsApi.md#read) | **GET** {artifact_href} | Inspect an artifact
*PulpcoreClient::ContentApi* | [**list**](docs/ContentApi.md#list) | **GET** /pulp/api/v3/content/ | List content
*PulpcoreClient::ContentguardsApi* | [**list**](docs/ContentguardsApi.md#list) | **GET** /pulp/api/v3/contentguards/ | List content guards
*PulpcoreClient::ContentguardsRbacApi* | [**assign_permission**](docs/ContentguardsRbacApi.md#assign_permission) | **POST** {r_b_a_c_content_guard_href}assign_permission/ | Add download permission
*PulpcoreClient::ContentguardsRbacApi* | [**create**](docs/ContentguardsRbacApi.md#create) | **POST** /pulp/api/v3/contentguards/core/rbac/ | Create a rbac content guard
*PulpcoreClient::ContentguardsRbacApi* | [**delete**](docs/ContentguardsRbacApi.md#delete) | **DELETE** {r_b_a_c_content_guard_href} | Delete a rbac content guard
*PulpcoreClient::ContentguardsRbacApi* | [**list**](docs/ContentguardsRbacApi.md#list) | **GET** /pulp/api/v3/contentguards/core/rbac/ | List rbac content guards
*PulpcoreClient::ContentguardsRbacApi* | [**partial_update**](docs/ContentguardsRbacApi.md#partial_update) | **PATCH** {r_b_a_c_content_guard_href} | Update a rbac content guard
*PulpcoreClient::ContentguardsRbacApi* | [**read**](docs/ContentguardsRbacApi.md#read) | **GET** {r_b_a_c_content_guard_href} | Inspect a rbac content guard
*PulpcoreClient::ContentguardsRbacApi* | [**remove_permission**](docs/ContentguardsRbacApi.md#remove_permission) | **POST** {r_b_a_c_content_guard_href}remove_permission/ | Remove download permission
*PulpcoreClient::ContentguardsRbacApi* | [**update**](docs/ContentguardsRbacApi.md#update) | **PUT** {r_b_a_c_content_guard_href} | Update a rbac content guard
*PulpcoreClient::ExportersFilesystemApi* | [**create**](docs/ExportersFilesystemApi.md#create) | **POST** /pulp/api/v3/exporters/core/filesystem/ | Create a filesystem exporter
*PulpcoreClient::ExportersFilesystemApi* | [**delete**](docs/ExportersFilesystemApi.md#delete) | **DELETE** {filesystem_exporter_href} | Delete a filesystem exporter
*PulpcoreClient::ExportersFilesystemApi* | [**list**](docs/ExportersFilesystemApi.md#list) | **GET** /pulp/api/v3/exporters/core/filesystem/ | List filesystem exporters
*PulpcoreClient::ExportersFilesystemApi* | [**partial_update**](docs/ExportersFilesystemApi.md#partial_update) | **PATCH** {filesystem_exporter_href} | Update a filesystem exporter
*PulpcoreClient::ExportersFilesystemApi* | [**read**](docs/ExportersFilesystemApi.md#read) | **GET** {filesystem_exporter_href} | Inspect a filesystem exporter
*PulpcoreClient::ExportersFilesystemApi* | [**update**](docs/ExportersFilesystemApi.md#update) | **PUT** {filesystem_exporter_href} | Update a filesystem exporter
*PulpcoreClient::ExportersFilesystemExportsApi* | [**create**](docs/ExportersFilesystemExportsApi.md#create) | **POST** {filesystem_exporter_href}exports/ | Create a filesystem export
*PulpcoreClient::ExportersFilesystemExportsApi* | [**delete**](docs/ExportersFilesystemExportsApi.md#delete) | **DELETE** {filesystem_filesystem_export_href} | Delete a filesystem export
*PulpcoreClient::ExportersFilesystemExportsApi* | [**list**](docs/ExportersFilesystemExportsApi.md#list) | **GET** {filesystem_exporter_href}exports/ | List filesystem exports
*PulpcoreClient::ExportersFilesystemExportsApi* | [**read**](docs/ExportersFilesystemExportsApi.md#read) | **GET** {filesystem_filesystem_export_href} | Inspect a filesystem export
*PulpcoreClient::ExportersPulpApi* | [**create**](docs/ExportersPulpApi.md#create) | **POST** /pulp/api/v3/exporters/core/pulp/ | Create a pulp exporter
*PulpcoreClient::ExportersPulpApi* | [**delete**](docs/ExportersPulpApi.md#delete) | **DELETE** {pulp_exporter_href} | Delete a pulp exporter
*PulpcoreClient::ExportersPulpApi* | [**list**](docs/ExportersPulpApi.md#list) | **GET** /pulp/api/v3/exporters/core/pulp/ | List pulp exporters
*PulpcoreClient::ExportersPulpApi* | [**partial_update**](docs/ExportersPulpApi.md#partial_update) | **PATCH** {pulp_exporter_href} | Update a pulp exporter
*PulpcoreClient::ExportersPulpApi* | [**read**](docs/ExportersPulpApi.md#read) | **GET** {pulp_exporter_href} | Inspect a pulp exporter
*PulpcoreClient::ExportersPulpApi* | [**update**](docs/ExportersPulpApi.md#update) | **PUT** {pulp_exporter_href} | Update a pulp exporter
*PulpcoreClient::ExportersPulpExportsApi* | [**create**](docs/ExportersPulpExportsApi.md#create) | **POST** {pulp_exporter_href}exports/ | Create a pulp export
*PulpcoreClient::ExportersPulpExportsApi* | [**delete**](docs/ExportersPulpExportsApi.md#delete) | **DELETE** {pulp_pulp_export_href} | Delete a pulp export
*PulpcoreClient::ExportersPulpExportsApi* | [**list**](docs/ExportersPulpExportsApi.md#list) | **GET** {pulp_exporter_href}exports/ | List pulp exports
*PulpcoreClient::ExportersPulpExportsApi* | [**read**](docs/ExportersPulpExportsApi.md#read) | **GET** {pulp_pulp_export_href} | Inspect a pulp export
*PulpcoreClient::GroupsApi* | [**create**](docs/GroupsApi.md#create) | **POST** /pulp/api/v3/groups/ | Create a group
*PulpcoreClient::GroupsApi* | [**delete**](docs/GroupsApi.md#delete) | **DELETE** {auth_group_href} | Delete a group
*PulpcoreClient::GroupsApi* | [**list**](docs/GroupsApi.md#list) | **GET** /pulp/api/v3/groups/ | List groups
*PulpcoreClient::GroupsApi* | [**partial_update**](docs/GroupsApi.md#partial_update) | **PATCH** {auth_group_href} | Update a group
*PulpcoreClient::GroupsApi* | [**read**](docs/GroupsApi.md#read) | **GET** {auth_group_href} | Inspect a group
*PulpcoreClient::GroupsApi* | [**update**](docs/GroupsApi.md#update) | **PUT** {auth_group_href} | Update a group
*PulpcoreClient::GroupsModelPermissionsApi* | [**create**](docs/GroupsModelPermissionsApi.md#create) | **POST** {auth_group_href}model_permissions/ | Create a permission
*PulpcoreClient::GroupsModelPermissionsApi* | [**delete**](docs/GroupsModelPermissionsApi.md#delete) | **DELETE** {auth_groups_model_permission_href} | Delete a permission
*PulpcoreClient::GroupsModelPermissionsApi* | [**list**](docs/GroupsModelPermissionsApi.md#list) | **GET** {auth_group_href}model_permissions/ | List permissions
*PulpcoreClient::GroupsModelPermissionsApi* | [**read**](docs/GroupsModelPermissionsApi.md#read) | **GET** {auth_groups_model_permission_href} | Inspect a permission
*PulpcoreClient::GroupsObjectPermissionsApi* | [**create**](docs/GroupsObjectPermissionsApi.md#create) | **POST** {auth_group_href}object_permissions/ | Create a permission
*PulpcoreClient::GroupsObjectPermissionsApi* | [**delete**](docs/GroupsObjectPermissionsApi.md#delete) | **DELETE** {auth_groups_object_permission_href} | Delete a permission
*PulpcoreClient::GroupsObjectPermissionsApi* | [**list**](docs/GroupsObjectPermissionsApi.md#list) | **GET** {auth_group_href}object_permissions/ | List permissions
*PulpcoreClient::GroupsObjectPermissionsApi* | [**read**](docs/GroupsObjectPermissionsApi.md#read) | **GET** {auth_groups_object_permission_href} | Inspect a permission
*PulpcoreClient::GroupsUsersApi* | [**create**](docs/GroupsUsersApi.md#create) | **POST** {auth_group_href}users/ | Create an user
*PulpcoreClient::GroupsUsersApi* | [**delete**](docs/GroupsUsersApi.md#delete) | **DELETE** {auth_groups_user_href} | Delete an user
*PulpcoreClient::GroupsUsersApi* | [**list**](docs/GroupsUsersApi.md#list) | **GET** {auth_group_href}users/ | List users
*PulpcoreClient::ImportersPulpApi* | [**create**](docs/ImportersPulpApi.md#create) | **POST** /pulp/api/v3/importers/core/pulp/ | Create a pulp importer
*PulpcoreClient::ImportersPulpApi* | [**delete**](docs/ImportersPulpApi.md#delete) | **DELETE** {pulp_importer_href} | Delete a pulp importer
*PulpcoreClient::ImportersPulpApi* | [**list**](docs/ImportersPulpApi.md#list) | **GET** /pulp/api/v3/importers/core/pulp/ | List pulp importers
*PulpcoreClient::ImportersPulpApi* | [**partial_update**](docs/ImportersPulpApi.md#partial_update) | **PATCH** {pulp_importer_href} | Update a pulp importer
*PulpcoreClient::ImportersPulpApi* | [**read**](docs/ImportersPulpApi.md#read) | **GET** {pulp_importer_href} | Inspect a pulp importer
*PulpcoreClient::ImportersPulpApi* | [**update**](docs/ImportersPulpApi.md#update) | **PUT** {pulp_importer_href} | Update a pulp importer
*PulpcoreClient::ImportersPulpImportCheckApi* | [**pulp_import_check_post**](docs/ImportersPulpImportCheckApi.md#pulp_import_check_post) | **POST** /pulp/api/v3/importers/core/pulp/import-check/ | Validate the parameters to be used for a PulpImport call
*PulpcoreClient::ImportersPulpImportsApi* | [**create**](docs/ImportersPulpImportsApi.md#create) | **POST** {pulp_importer_href}imports/ | Create a pulp import
*PulpcoreClient::ImportersPulpImportsApi* | [**delete**](docs/ImportersPulpImportsApi.md#delete) | **DELETE** {pulp_pulp_import_href} | Delete a pulp import
*PulpcoreClient::ImportersPulpImportsApi* | [**list**](docs/ImportersPulpImportsApi.md#list) | **GET** {pulp_importer_href}imports/ | List pulp imports
*PulpcoreClient::ImportersPulpImportsApi* | [**read**](docs/ImportersPulpImportsApi.md#read) | **GET** {pulp_pulp_import_href} | Inspect a pulp import
*PulpcoreClient::OrphansApi* | [**delete**](docs/OrphansApi.md#delete) | **DELETE** /pulp/api/v3/orphans/ | Delete orphans
*PulpcoreClient::OrphansCleanupApi* | [**cleanup**](docs/OrphansCleanupApi.md#cleanup) | **POST** /pulp/api/v3/orphans/cleanup/ | 
*PulpcoreClient::PublicationsApi* | [**list**](docs/PublicationsApi.md#list) | **GET** /pulp/api/v3/publications/ | List publications
*PulpcoreClient::RepairApi* | [**post**](docs/RepairApi.md#post) | **POST** /pulp/api/v3/repair/ | Repair Artifact Storage
*PulpcoreClient::RepositoriesApi* | [**list**](docs/RepositoriesApi.md#list) | **GET** /pulp/api/v3/repositories/ | List repositories
*PulpcoreClient::RepositoriesReclaimSpaceApi* | [**reclaim**](docs/RepositoriesReclaimSpaceApi.md#reclaim) | **POST** /pulp/api/v3/repositories/reclaim_space/ | 
*PulpcoreClient::RepositoryVersionsApi* | [**list**](docs/RepositoryVersionsApi.md#list) | **GET** /pulp/api/v3/repository_versions/ | List repository versions
*PulpcoreClient::SigningServicesApi* | [**list**](docs/SigningServicesApi.md#list) | **GET** /pulp/api/v3/signing-services/ | List signing services
*PulpcoreClient::SigningServicesApi* | [**read**](docs/SigningServicesApi.md#read) | **GET** {signing_service_href} | Inspect a signing service
*PulpcoreClient::StatusApi* | [**status_read**](docs/StatusApi.md#status_read) | **GET** /pulp/api/v3/status/ | Inspect status of Pulp
*PulpcoreClient::TaskGroupsApi* | [**list**](docs/TaskGroupsApi.md#list) | **GET** /pulp/api/v3/task-groups/ | List task groups
*PulpcoreClient::TaskGroupsApi* | [**read**](docs/TaskGroupsApi.md#read) | **GET** {task_group_href} | Inspect a task group
*PulpcoreClient::TasksApi* | [**delete**](docs/TasksApi.md#delete) | **DELETE** {task_href} | Delete a task
*PulpcoreClient::TasksApi* | [**list**](docs/TasksApi.md#list) | **GET** /pulp/api/v3/tasks/ | List tasks
*PulpcoreClient::TasksApi* | [**read**](docs/TasksApi.md#read) | **GET** {task_href} | Inspect a task
*PulpcoreClient::TasksApi* | [**tasks_cancel**](docs/TasksApi.md#tasks_cancel) | **PATCH** {task_href} | Cancel a task
*PulpcoreClient::UploadsApi* | [**commit**](docs/UploadsApi.md#commit) | **POST** {upload_href}commit/ | Finish an Upload
*PulpcoreClient::UploadsApi* | [**create**](docs/UploadsApi.md#create) | **POST** /pulp/api/v3/uploads/ | Create an upload
*PulpcoreClient::UploadsApi* | [**delete**](docs/UploadsApi.md#delete) | **DELETE** {upload_href} | Delete an upload
*PulpcoreClient::UploadsApi* | [**list**](docs/UploadsApi.md#list) | **GET** /pulp/api/v3/uploads/ | List uploads
*PulpcoreClient::UploadsApi* | [**read**](docs/UploadsApi.md#read) | **GET** {upload_href} | Inspect an upload
*PulpcoreClient::UploadsApi* | [**update**](docs/UploadsApi.md#update) | **PUT** {upload_href} | Upload a file chunk
*PulpcoreClient::UsersApi* | [**list**](docs/UsersApi.md#list) | **GET** /pulp/api/v3/users/ | List users
*PulpcoreClient::UsersApi* | [**permissions**](docs/UsersApi.md#permissions) | **GET** {auth_user_href}permissions/ | 
*PulpcoreClient::UsersApi* | [**read**](docs/UsersApi.md#read) | **GET** {auth_user_href} | Inspect an user
*PulpcoreClient::WorkersApi* | [**list**](docs/WorkersApi.md#list) | **GET** /pulp/api/v3/workers/ | List workers
*PulpcoreClient::WorkersApi* | [**read**](docs/WorkersApi.md#read) | **GET** {worker_href} | Inspect a worker


## Documentation for Models

 - [PulpcoreClient::AccessPolicy](docs/AccessPolicy.md)
 - [PulpcoreClient::AccessPolicyResponse](docs/AccessPolicyResponse.md)
 - [PulpcoreClient::Artifact](docs/Artifact.md)
 - [PulpcoreClient::ArtifactResponse](docs/ArtifactResponse.md)
 - [PulpcoreClient::AsyncOperationResponse](docs/AsyncOperationResponse.md)
 - [PulpcoreClient::ContentAppStatusResponse](docs/ContentAppStatusResponse.md)
 - [PulpcoreClient::ContentGuardResponse](docs/ContentGuardResponse.md)
 - [PulpcoreClient::ContentSummaryResponse](docs/ContentSummaryResponse.md)
 - [PulpcoreClient::DatabaseConnectionResponse](docs/DatabaseConnectionResponse.md)
 - [PulpcoreClient::EvaluationResponse](docs/EvaluationResponse.md)
 - [PulpcoreClient::FilesystemExport](docs/FilesystemExport.md)
 - [PulpcoreClient::FilesystemExportResponse](docs/FilesystemExportResponse.md)
 - [PulpcoreClient::FilesystemExporter](docs/FilesystemExporter.md)
 - [PulpcoreClient::FilesystemExporterResponse](docs/FilesystemExporterResponse.md)
 - [PulpcoreClient::Group](docs/Group.md)
 - [PulpcoreClient::GroupProgressReportResponse](docs/GroupProgressReportResponse.md)
 - [PulpcoreClient::GroupResponse](docs/GroupResponse.md)
 - [PulpcoreClient::GroupUser](docs/GroupUser.md)
 - [PulpcoreClient::GroupUserResponse](docs/GroupUserResponse.md)
 - [PulpcoreClient::ImportResponse](docs/ImportResponse.md)
 - [PulpcoreClient::MethodEnum](docs/MethodEnum.md)
 - [PulpcoreClient::MinimalTaskResponse](docs/MinimalTaskResponse.md)
 - [PulpcoreClient::MultipleArtifactContentResponse](docs/MultipleArtifactContentResponse.md)
 - [PulpcoreClient::OrphansCleanup](docs/OrphansCleanup.md)
 - [PulpcoreClient::PaginatedAccessPolicyResponseList](docs/PaginatedAccessPolicyResponseList.md)
 - [PulpcoreClient::PaginatedArtifactResponseList](docs/PaginatedArtifactResponseList.md)
 - [PulpcoreClient::PaginatedContentGuardResponseList](docs/PaginatedContentGuardResponseList.md)
 - [PulpcoreClient::PaginatedFilesystemExportResponseList](docs/PaginatedFilesystemExportResponseList.md)
 - [PulpcoreClient::PaginatedFilesystemExporterResponseList](docs/PaginatedFilesystemExporterResponseList.md)
 - [PulpcoreClient::PaginatedGroupResponseList](docs/PaginatedGroupResponseList.md)
 - [PulpcoreClient::PaginatedGroupUserResponseList](docs/PaginatedGroupUserResponseList.md)
 - [PulpcoreClient::PaginatedImportResponseList](docs/PaginatedImportResponseList.md)
 - [PulpcoreClient::PaginatedMultipleArtifactContentResponseList](docs/PaginatedMultipleArtifactContentResponseList.md)
 - [PulpcoreClient::PaginatedPermissionResponseList](docs/PaginatedPermissionResponseList.md)
 - [PulpcoreClient::PaginatedPublicationResponseList](docs/PaginatedPublicationResponseList.md)
 - [PulpcoreClient::PaginatedPulpExportResponseList](docs/PaginatedPulpExportResponseList.md)
 - [PulpcoreClient::PaginatedPulpExporterResponseList](docs/PaginatedPulpExporterResponseList.md)
 - [PulpcoreClient::PaginatedPulpImporterResponseList](docs/PaginatedPulpImporterResponseList.md)
 - [PulpcoreClient::PaginatedRBACContentGuardResponseList](docs/PaginatedRBACContentGuardResponseList.md)
 - [PulpcoreClient::PaginatedRepositoryResponseList](docs/PaginatedRepositoryResponseList.md)
 - [PulpcoreClient::PaginatedRepositoryVersionResponseList](docs/PaginatedRepositoryVersionResponseList.md)
 - [PulpcoreClient::PaginatedSigningServiceResponseList](docs/PaginatedSigningServiceResponseList.md)
 - [PulpcoreClient::PaginatedTaskGroupResponseList](docs/PaginatedTaskGroupResponseList.md)
 - [PulpcoreClient::PaginatedTaskResponseList](docs/PaginatedTaskResponseList.md)
 - [PulpcoreClient::PaginatedUploadResponseList](docs/PaginatedUploadResponseList.md)
 - [PulpcoreClient::PaginatedUserResponseList](docs/PaginatedUserResponseList.md)
 - [PulpcoreClient::PaginatedWorkerResponseList](docs/PaginatedWorkerResponseList.md)
 - [PulpcoreClient::PatchedAccessPolicy](docs/PatchedAccessPolicy.md)
 - [PulpcoreClient::PatchedFilesystemExporter](docs/PatchedFilesystemExporter.md)
 - [PulpcoreClient::PatchedGroup](docs/PatchedGroup.md)
 - [PulpcoreClient::PatchedPulpExporter](docs/PatchedPulpExporter.md)
 - [PulpcoreClient::PatchedPulpImporter](docs/PatchedPulpImporter.md)
 - [PulpcoreClient::PatchedRBACContentGuard](docs/PatchedRBACContentGuard.md)
 - [PulpcoreClient::PatchedTaskCancel](docs/PatchedTaskCancel.md)
 - [PulpcoreClient::PermissionResponse](docs/PermissionResponse.md)
 - [PulpcoreClient::ProgressReportResponse](docs/ProgressReportResponse.md)
 - [PulpcoreClient::PublicationResponse](docs/PublicationResponse.md)
 - [PulpcoreClient::PulpExport](docs/PulpExport.md)
 - [PulpcoreClient::PulpExportResponse](docs/PulpExportResponse.md)
 - [PulpcoreClient::PulpExporter](docs/PulpExporter.md)
 - [PulpcoreClient::PulpExporterResponse](docs/PulpExporterResponse.md)
 - [PulpcoreClient::PulpImport](docs/PulpImport.md)
 - [PulpcoreClient::PulpImportCheck](docs/PulpImportCheck.md)
 - [PulpcoreClient::PulpImportCheckResponse](docs/PulpImportCheckResponse.md)
 - [PulpcoreClient::PulpImporter](docs/PulpImporter.md)
 - [PulpcoreClient::PulpImporterResponse](docs/PulpImporterResponse.md)
 - [PulpcoreClient::RBACContentGuard](docs/RBACContentGuard.md)
 - [PulpcoreClient::RBACContentGuardPermission](docs/RBACContentGuardPermission.md)
 - [PulpcoreClient::RBACContentGuardResponse](docs/RBACContentGuardResponse.md)
 - [PulpcoreClient::ReclaimSpace](docs/ReclaimSpace.md)
 - [PulpcoreClient::RedisConnectionResponse](docs/RedisConnectionResponse.md)
 - [PulpcoreClient::Repair](docs/Repair.md)
 - [PulpcoreClient::RepositoryResponse](docs/RepositoryResponse.md)
 - [PulpcoreClient::RepositoryVersionResponse](docs/RepositoryVersionResponse.md)
 - [PulpcoreClient::SigningServiceResponse](docs/SigningServiceResponse.md)
 - [PulpcoreClient::StatusResponse](docs/StatusResponse.md)
 - [PulpcoreClient::StorageResponse](docs/StorageResponse.md)
 - [PulpcoreClient::TaskGroupOperationResponse](docs/TaskGroupOperationResponse.md)
 - [PulpcoreClient::TaskGroupResponse](docs/TaskGroupResponse.md)
 - [PulpcoreClient::TaskResponse](docs/TaskResponse.md)
 - [PulpcoreClient::Upload](docs/Upload.md)
 - [PulpcoreClient::UploadChunk](docs/UploadChunk.md)
 - [PulpcoreClient::UploadChunkResponse](docs/UploadChunkResponse.md)
 - [PulpcoreClient::UploadCommit](docs/UploadCommit.md)
 - [PulpcoreClient::UploadDetailResponse](docs/UploadDetailResponse.md)
 - [PulpcoreClient::UploadResponse](docs/UploadResponse.md)
 - [PulpcoreClient::UserGroupResponse](docs/UserGroupResponse.md)
 - [PulpcoreClient::UserResponse](docs/UserResponse.md)
 - [PulpcoreClient::VersionResponse](docs/VersionResponse.md)
 - [PulpcoreClient::WorkerResponse](docs/WorkerResponse.md)


## Documentation for Authorization


### basicAuth

- **Type**: HTTP basic authentication

