# PulpcoreClient::ContentguardsRbacApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**assign_permission**](ContentguardsRbacApi.md#assign_permission) | **POST** {r_b_a_c_content_guard_href}assign_permission/ | Add download permission
[**create**](ContentguardsRbacApi.md#create) | **POST** /pulp/api/v3/contentguards/core/rbac/ | Create a rbac content guard
[**delete**](ContentguardsRbacApi.md#delete) | **DELETE** {r_b_a_c_content_guard_href} | Delete a rbac content guard
[**list**](ContentguardsRbacApi.md#list) | **GET** /pulp/api/v3/contentguards/core/rbac/ | List rbac content guards
[**partial_update**](ContentguardsRbacApi.md#partial_update) | **PATCH** {r_b_a_c_content_guard_href} | Update a rbac content guard
[**read**](ContentguardsRbacApi.md#read) | **GET** {r_b_a_c_content_guard_href} | Inspect a rbac content guard
[**remove_permission**](ContentguardsRbacApi.md#remove_permission) | **POST** {r_b_a_c_content_guard_href}remove_permission/ | Remove download permission
[**update**](ContentguardsRbacApi.md#update) | **PUT** {r_b_a_c_content_guard_href} | Update a rbac content guard



## assign_permission

> RBACContentGuardResponse assign_permission(r_b_a_c_content_guard_href, rbac_content_guard_permission)

Add download permission

Give users and groups the `download` permission

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ContentguardsRbacApi.new
r_b_a_c_content_guard_href = 'r_b_a_c_content_guard_href_example' # String | 
rbac_content_guard_permission = PulpcoreClient::RBACContentGuardPermission.new # RBACContentGuardPermission | 

begin
  #Add download permission
  result = api_instance.assign_permission(r_b_a_c_content_guard_href, rbac_content_guard_permission)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ContentguardsRbacApi->assign_permission: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **r_b_a_c_content_guard_href** | **String**|  | 
 **rbac_content_guard_permission** | [**RBACContentGuardPermission**](RBACContentGuardPermission.md)|  | 

### Return type

[**RBACContentGuardResponse**](RBACContentGuardResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## create

> RBACContentGuardResponse create(rbac_content_guard)

Create a rbac content guard

Viewset for creating contentguards that use RBAC to protect content. Has add and remove actions for managing permission for users and groups to download content protected by this guard.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ContentguardsRbacApi.new
rbac_content_guard = PulpcoreClient::RBACContentGuard.new # RBACContentGuard | 

begin
  #Create a rbac content guard
  result = api_instance.create(rbac_content_guard)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ContentguardsRbacApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **rbac_content_guard** | [**RBACContentGuard**](RBACContentGuard.md)|  | 

### Return type

[**RBACContentGuardResponse**](RBACContentGuardResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## delete

> delete(r_b_a_c_content_guard_href)

Delete a rbac content guard

Viewset for creating contentguards that use RBAC to protect content. Has add and remove actions for managing permission for users and groups to download content protected by this guard.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ContentguardsRbacApi.new
r_b_a_c_content_guard_href = 'r_b_a_c_content_guard_href_example' # String | 

begin
  #Delete a rbac content guard
  api_instance.delete(r_b_a_c_content_guard_href)
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ContentguardsRbacApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **r_b_a_c_content_guard_href** | **String**|  | 

### Return type

nil (empty response body)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## list

> PaginatedRBACContentGuardResponseList list(opts)

List rbac content guards

Viewset for creating contentguards that use RBAC to protect content. Has add and remove actions for managing permission for users and groups to download content protected by this guard.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ContentguardsRbacApi.new
opts = {
  limit: 56, # Integer | Number of results to return per page.
  name: 'name_example', # String | 
  name__contains: 'name__contains_example', # String | Filter results where name contains value
  name__icontains: 'name__icontains_example', # String | Filter results where name contains value
  name__in: ['name__in_example'], # Array<String> | Filter results where name is in a comma-separated list of values
  name__startswith: 'name__startswith_example', # String | Filter results where name starts with value
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List rbac content guards
  result = api_instance.list(opts)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ContentguardsRbacApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **name** | **String**|  | [optional] 
 **name__contains** | **String**| Filter results where name contains value | [optional] 
 **name__icontains** | **String**| Filter results where name contains value | [optional] 
 **name__in** | [**Array&lt;String&gt;**](String.md)| Filter results where name is in a comma-separated list of values | [optional] 
 **name__startswith** | **String**| Filter results where name starts with value | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedRBACContentGuardResponseList**](PaginatedRBACContentGuardResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## partial_update

> RBACContentGuardResponse partial_update(r_b_a_c_content_guard_href, patched_rbac_content_guard)

Update a rbac content guard

Viewset for creating contentguards that use RBAC to protect content. Has add and remove actions for managing permission for users and groups to download content protected by this guard.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ContentguardsRbacApi.new
r_b_a_c_content_guard_href = 'r_b_a_c_content_guard_href_example' # String | 
patched_rbac_content_guard = PulpcoreClient::PatchedRBACContentGuard.new # PatchedRBACContentGuard | 

begin
  #Update a rbac content guard
  result = api_instance.partial_update(r_b_a_c_content_guard_href, patched_rbac_content_guard)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ContentguardsRbacApi->partial_update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **r_b_a_c_content_guard_href** | **String**|  | 
 **patched_rbac_content_guard** | [**PatchedRBACContentGuard**](PatchedRBACContentGuard.md)|  | 

### Return type

[**RBACContentGuardResponse**](RBACContentGuardResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## read

> RBACContentGuardResponse read(r_b_a_c_content_guard_href, opts)

Inspect a rbac content guard

Viewset for creating contentguards that use RBAC to protect content. Has add and remove actions for managing permission for users and groups to download content protected by this guard.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ContentguardsRbacApi.new
r_b_a_c_content_guard_href = 'r_b_a_c_content_guard_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect a rbac content guard
  result = api_instance.read(r_b_a_c_content_guard_href, opts)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ContentguardsRbacApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **r_b_a_c_content_guard_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**RBACContentGuardResponse**](RBACContentGuardResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## remove_permission

> RBACContentGuardResponse remove_permission(r_b_a_c_content_guard_href, rbac_content_guard_permission)

Remove download permission

Remove `download` permission from users and groups

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ContentguardsRbacApi.new
r_b_a_c_content_guard_href = 'r_b_a_c_content_guard_href_example' # String | 
rbac_content_guard_permission = PulpcoreClient::RBACContentGuardPermission.new # RBACContentGuardPermission | 

begin
  #Remove download permission
  result = api_instance.remove_permission(r_b_a_c_content_guard_href, rbac_content_guard_permission)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ContentguardsRbacApi->remove_permission: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **r_b_a_c_content_guard_href** | **String**|  | 
 **rbac_content_guard_permission** | [**RBACContentGuardPermission**](RBACContentGuardPermission.md)|  | 

### Return type

[**RBACContentGuardResponse**](RBACContentGuardResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## update

> RBACContentGuardResponse update(r_b_a_c_content_guard_href, rbac_content_guard)

Update a rbac content guard

Viewset for creating contentguards that use RBAC to protect content. Has add and remove actions for managing permission for users and groups to download content protected by this guard.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ContentguardsRbacApi.new
r_b_a_c_content_guard_href = 'r_b_a_c_content_guard_href_example' # String | 
rbac_content_guard = PulpcoreClient::RBACContentGuard.new # RBACContentGuard | 

begin
  #Update a rbac content guard
  result = api_instance.update(r_b_a_c_content_guard_href, rbac_content_guard)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ContentguardsRbacApi->update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **r_b_a_c_content_guard_href** | **String**|  | 
 **rbac_content_guard** | [**RBACContentGuard**](RBACContentGuard.md)|  | 

### Return type

[**RBACContentGuardResponse**](RBACContentGuardResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json

