# PulpcoreClient::ExportersFilesystemApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](ExportersFilesystemApi.md#create) | **POST** /pulp/api/v3/exporters/core/filesystem/ | Create a filesystem exporter
[**delete**](ExportersFilesystemApi.md#delete) | **DELETE** {filesystem_exporter_href} | Delete a filesystem exporter
[**list**](ExportersFilesystemApi.md#list) | **GET** /pulp/api/v3/exporters/core/filesystem/ | List filesystem exporters
[**partial_update**](ExportersFilesystemApi.md#partial_update) | **PATCH** {filesystem_exporter_href} | Update a filesystem exporter
[**read**](ExportersFilesystemApi.md#read) | **GET** {filesystem_exporter_href} | Inspect a filesystem exporter
[**update**](ExportersFilesystemApi.md#update) | **PUT** {filesystem_exporter_href} | Update a filesystem exporter



## create

> FilesystemExporterResponse create(filesystem_exporter)

Create a filesystem exporter

Endpoint for managing FilesystemExporters. FilesystemExporters are provided as a tech preview.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ExportersFilesystemApi.new
filesystem_exporter = PulpcoreClient::FilesystemExporter.new # FilesystemExporter | 

begin
  #Create a filesystem exporter
  result = api_instance.create(filesystem_exporter)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ExportersFilesystemApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **filesystem_exporter** | [**FilesystemExporter**](FilesystemExporter.md)|  | 

### Return type

[**FilesystemExporterResponse**](FilesystemExporterResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## delete

> AsyncOperationResponse delete(filesystem_exporter_href)

Delete a filesystem exporter

Trigger an asynchronous delete task

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ExportersFilesystemApi.new
filesystem_exporter_href = 'filesystem_exporter_href_example' # String | 

begin
  #Delete a filesystem exporter
  result = api_instance.delete(filesystem_exporter_href)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ExportersFilesystemApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **filesystem_exporter_href** | **String**|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list

> PaginatedFilesystemExporterResponseList list(opts)

List filesystem exporters

Endpoint for managing FilesystemExporters. FilesystemExporters are provided as a tech preview.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ExportersFilesystemApi.new
opts = {
  limit: 56, # Integer | Number of results to return per page.
  name: 'name_example', # String | 
  name__contains: 'name__contains_example', # String | Filter results where name contains value
  name__icontains: 'name__icontains_example', # String | Filter results where name contains value
  name__in: ['name__in_example'], # Array<String> | Filter results where name is in a comma-separated list of values
  name__startswith: 'name__startswith_example', # String | Filter results where name starts with value
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List filesystem exporters
  result = api_instance.list(opts)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ExportersFilesystemApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **name** | **String**|  | [optional] 
 **name__contains** | **String**| Filter results where name contains value | [optional] 
 **name__icontains** | **String**| Filter results where name contains value | [optional] 
 **name__in** | [**Array&lt;String&gt;**](String.md)| Filter results where name is in a comma-separated list of values | [optional] 
 **name__startswith** | **String**| Filter results where name starts with value | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedFilesystemExporterResponseList**](PaginatedFilesystemExporterResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## partial_update

> AsyncOperationResponse partial_update(filesystem_exporter_href, patched_filesystem_exporter)

Update a filesystem exporter

Trigger an asynchronous partial update task

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ExportersFilesystemApi.new
filesystem_exporter_href = 'filesystem_exporter_href_example' # String | 
patched_filesystem_exporter = PulpcoreClient::PatchedFilesystemExporter.new # PatchedFilesystemExporter | 

begin
  #Update a filesystem exporter
  result = api_instance.partial_update(filesystem_exporter_href, patched_filesystem_exporter)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ExportersFilesystemApi->partial_update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **filesystem_exporter_href** | **String**|  | 
 **patched_filesystem_exporter** | [**PatchedFilesystemExporter**](PatchedFilesystemExporter.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## read

> FilesystemExporterResponse read(filesystem_exporter_href, opts)

Inspect a filesystem exporter

Endpoint for managing FilesystemExporters. FilesystemExporters are provided as a tech preview.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ExportersFilesystemApi.new
filesystem_exporter_href = 'filesystem_exporter_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect a filesystem exporter
  result = api_instance.read(filesystem_exporter_href, opts)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ExportersFilesystemApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **filesystem_exporter_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**FilesystemExporterResponse**](FilesystemExporterResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update

> AsyncOperationResponse update(filesystem_exporter_href, filesystem_exporter)

Update a filesystem exporter

Trigger an asynchronous update task

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ExportersFilesystemApi.new
filesystem_exporter_href = 'filesystem_exporter_href_example' # String | 
filesystem_exporter = PulpcoreClient::FilesystemExporter.new # FilesystemExporter | 

begin
  #Update a filesystem exporter
  result = api_instance.update(filesystem_exporter_href, filesystem_exporter)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ExportersFilesystemApi->update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **filesystem_exporter_href** | **String**|  | 
 **filesystem_exporter** | [**FilesystemExporter**](FilesystemExporter.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json

