# PulpcoreClient::ExportersFilesystemExportsApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](ExportersFilesystemExportsApi.md#create) | **POST** {filesystem_exporter_href}exports/ | Create a filesystem export
[**delete**](ExportersFilesystemExportsApi.md#delete) | **DELETE** {filesystem_filesystem_export_href} | Delete a filesystem export
[**list**](ExportersFilesystemExportsApi.md#list) | **GET** {filesystem_exporter_href}exports/ | List filesystem exports
[**read**](ExportersFilesystemExportsApi.md#read) | **GET** {filesystem_filesystem_export_href} | Inspect a filesystem export



## create

> AsyncOperationResponse create(filesystem_exporter_href, filesystem_export)

Create a filesystem export

Trigger an asynchronous task to export files to the filesystem

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ExportersFilesystemExportsApi.new
filesystem_exporter_href = 'filesystem_exporter_href_example' # String | 
filesystem_export = PulpcoreClient::FilesystemExport.new # FilesystemExport | 

begin
  #Create a filesystem export
  result = api_instance.create(filesystem_exporter_href, filesystem_export)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ExportersFilesystemExportsApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **filesystem_exporter_href** | **String**|  | 
 **filesystem_export** | [**FilesystemExport**](FilesystemExport.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## delete

> delete(filesystem_filesystem_export_href)

Delete a filesystem export

Endpoint for managing FilesystemExports. This endpoint is provided as a tech preview.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ExportersFilesystemExportsApi.new
filesystem_filesystem_export_href = 'filesystem_filesystem_export_href_example' # String | 

begin
  #Delete a filesystem export
  api_instance.delete(filesystem_filesystem_export_href)
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ExportersFilesystemExportsApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **filesystem_filesystem_export_href** | **String**|  | 

### Return type

nil (empty response body)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## list

> PaginatedFilesystemExportResponseList list(filesystem_exporter_href, opts)

List filesystem exports

Endpoint for managing FilesystemExports. This endpoint is provided as a tech preview.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ExportersFilesystemExportsApi.new
filesystem_exporter_href = 'filesystem_exporter_href_example' # String | 
opts = {
  limit: 56, # Integer | Number of results to return per page.
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List filesystem exports
  result = api_instance.list(filesystem_exporter_href, opts)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ExportersFilesystemExportsApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **filesystem_exporter_href** | **String**|  | 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedFilesystemExportResponseList**](PaginatedFilesystemExportResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> FilesystemExportResponse read(filesystem_filesystem_export_href, opts)

Inspect a filesystem export

Endpoint for managing FilesystemExports. This endpoint is provided as a tech preview.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ExportersFilesystemExportsApi.new
filesystem_filesystem_export_href = 'filesystem_filesystem_export_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect a filesystem export
  result = api_instance.read(filesystem_filesystem_export_href, opts)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ExportersFilesystemExportsApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **filesystem_filesystem_export_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**FilesystemExportResponse**](FilesystemExportResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

