# PulpcoreClient::ExportersPulpApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](ExportersPulpApi.md#create) | **POST** /pulp/api/v3/exporters/core/pulp/ | Create a pulp exporter
[**delete**](ExportersPulpApi.md#delete) | **DELETE** {pulp_exporter_href} | Delete a pulp exporter
[**list**](ExportersPulpApi.md#list) | **GET** /pulp/api/v3/exporters/core/pulp/ | List pulp exporters
[**partial_update**](ExportersPulpApi.md#partial_update) | **PATCH** {pulp_exporter_href} | Update a pulp exporter
[**read**](ExportersPulpApi.md#read) | **GET** {pulp_exporter_href} | Inspect a pulp exporter
[**update**](ExportersPulpApi.md#update) | **PUT** {pulp_exporter_href} | Update a pulp exporter



## create

> PulpExporterResponse create(pulp_exporter)

Create a pulp exporter

ViewSet for viewing PulpExporters.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ExportersPulpApi.new
pulp_exporter = PulpcoreClient::PulpExporter.new # PulpExporter | 

begin
  #Create a pulp exporter
  result = api_instance.create(pulp_exporter)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ExportersPulpApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **pulp_exporter** | [**PulpExporter**](PulpExporter.md)|  | 

### Return type

[**PulpExporterResponse**](PulpExporterResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## delete

> AsyncOperationResponse delete(pulp_exporter_href)

Delete a pulp exporter

Trigger an asynchronous delete task

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ExportersPulpApi.new
pulp_exporter_href = 'pulp_exporter_href_example' # String | 

begin
  #Delete a pulp exporter
  result = api_instance.delete(pulp_exporter_href)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ExportersPulpApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **pulp_exporter_href** | **String**|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list

> PaginatedPulpExporterResponseList list(opts)

List pulp exporters

ViewSet for viewing PulpExporters.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ExportersPulpApi.new
opts = {
  limit: 56, # Integer | Number of results to return per page.
  name: 'name_example', # String | 
  name__contains: 'name__contains_example', # String | Filter results where name contains value
  name__icontains: 'name__icontains_example', # String | Filter results where name contains value
  name__in: ['name__in_example'], # Array<String> | Filter results where name is in a comma-separated list of values
  name__startswith: 'name__startswith_example', # String | Filter results where name starts with value
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List pulp exporters
  result = api_instance.list(opts)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ExportersPulpApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **name** | **String**|  | [optional] 
 **name__contains** | **String**| Filter results where name contains value | [optional] 
 **name__icontains** | **String**| Filter results where name contains value | [optional] 
 **name__in** | [**Array&lt;String&gt;**](String.md)| Filter results where name is in a comma-separated list of values | [optional] 
 **name__startswith** | **String**| Filter results where name starts with value | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedPulpExporterResponseList**](PaginatedPulpExporterResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## partial_update

> AsyncOperationResponse partial_update(pulp_exporter_href, patched_pulp_exporter)

Update a pulp exporter

Trigger an asynchronous partial update task

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ExportersPulpApi.new
pulp_exporter_href = 'pulp_exporter_href_example' # String | 
patched_pulp_exporter = PulpcoreClient::PatchedPulpExporter.new # PatchedPulpExporter | 

begin
  #Update a pulp exporter
  result = api_instance.partial_update(pulp_exporter_href, patched_pulp_exporter)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ExportersPulpApi->partial_update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **pulp_exporter_href** | **String**|  | 
 **patched_pulp_exporter** | [**PatchedPulpExporter**](PatchedPulpExporter.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## read

> PulpExporterResponse read(pulp_exporter_href, opts)

Inspect a pulp exporter

ViewSet for viewing PulpExporters.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ExportersPulpApi.new
pulp_exporter_href = 'pulp_exporter_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect a pulp exporter
  result = api_instance.read(pulp_exporter_href, opts)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ExportersPulpApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **pulp_exporter_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PulpExporterResponse**](PulpExporterResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update

> AsyncOperationResponse update(pulp_exporter_href, pulp_exporter)

Update a pulp exporter

Trigger an asynchronous update task

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ExportersPulpApi.new
pulp_exporter_href = 'pulp_exporter_href_example' # String | 
pulp_exporter = PulpcoreClient::PulpExporter.new # PulpExporter | 

begin
  #Update a pulp exporter
  result = api_instance.update(pulp_exporter_href, pulp_exporter)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ExportersPulpApi->update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **pulp_exporter_href** | **String**|  | 
 **pulp_exporter** | [**PulpExporter**](PulpExporter.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json

