# PulpcoreClient::ExportersPulpExportsApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](ExportersPulpExportsApi.md#create) | **POST** {pulp_exporter_href}exports/ | Create a pulp export
[**delete**](ExportersPulpExportsApi.md#delete) | **DELETE** {pulp_pulp_export_href} | Delete a pulp export
[**list**](ExportersPulpExportsApi.md#list) | **GET** {pulp_exporter_href}exports/ | List pulp exports
[**read**](ExportersPulpExportsApi.md#read) | **GET** {pulp_pulp_export_href} | Inspect a pulp export



## create

> AsyncOperationResponse create(pulp_exporter_href, pulp_export)

Create a pulp export

Trigger an asynchronous task to export a set of repositories

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ExportersPulpExportsApi.new
pulp_exporter_href = 'pulp_exporter_href_example' # String | 
pulp_export = PulpcoreClient::PulpExport.new # PulpExport | 

begin
  #Create a pulp export
  result = api_instance.create(pulp_exporter_href, pulp_export)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ExportersPulpExportsApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **pulp_exporter_href** | **String**|  | 
 **pulp_export** | [**PulpExport**](PulpExport.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## delete

> delete(pulp_pulp_export_href)

Delete a pulp export

ViewSet for viewing exports from a PulpExporter.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ExportersPulpExportsApi.new
pulp_pulp_export_href = 'pulp_pulp_export_href_example' # String | 

begin
  #Delete a pulp export
  api_instance.delete(pulp_pulp_export_href)
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ExportersPulpExportsApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **pulp_pulp_export_href** | **String**|  | 

### Return type

nil (empty response body)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## list

> PaginatedPulpExportResponseList list(pulp_exporter_href, opts)

List pulp exports

ViewSet for viewing exports from a PulpExporter.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ExportersPulpExportsApi.new
pulp_exporter_href = 'pulp_exporter_href_example' # String | 
opts = {
  limit: 56, # Integer | Number of results to return per page.
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List pulp exports
  result = api_instance.list(pulp_exporter_href, opts)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ExportersPulpExportsApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **pulp_exporter_href** | **String**|  | 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedPulpExportResponseList**](PaginatedPulpExportResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> PulpExportResponse read(pulp_pulp_export_href, opts)

Inspect a pulp export

ViewSet for viewing exports from a PulpExporter.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::ExportersPulpExportsApi.new
pulp_pulp_export_href = 'pulp_pulp_export_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect a pulp export
  result = api_instance.read(pulp_pulp_export_href, opts)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling ExportersPulpExportsApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **pulp_pulp_export_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PulpExportResponse**](PulpExportResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

