# PulpcoreClient::GroupsApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](GroupsApi.md#create) | **POST** /pulp/api/v3/groups/ | Create a group
[**delete**](GroupsApi.md#delete) | **DELETE** {auth_group_href} | Delete a group
[**list**](GroupsApi.md#list) | **GET** /pulp/api/v3/groups/ | List groups
[**partial_update**](GroupsApi.md#partial_update) | **PATCH** {auth_group_href} | Update a group
[**read**](GroupsApi.md#read) | **GET** {auth_group_href} | Inspect a group
[**update**](GroupsApi.md#update) | **PUT** {auth_group_href} | Update a group



## create

> GroupResponse create(group)

Create a group

ViewSet for Group.  NOTE: This API endpoint is in \"tech preview\" and subject to change

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::GroupsApi.new
group = PulpcoreClient::Group.new # Group | 

begin
  #Create a group
  result = api_instance.create(group)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling GroupsApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **group** | [**Group**](Group.md)|  | 

### Return type

[**GroupResponse**](GroupResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## delete

> delete(auth_group_href)

Delete a group

ViewSet for Group.  NOTE: This API endpoint is in \"tech preview\" and subject to change

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::GroupsApi.new
auth_group_href = 'auth_group_href_example' # String | 

begin
  #Delete a group
  api_instance.delete(auth_group_href)
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling GroupsApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **auth_group_href** | **String**|  | 

### Return type

nil (empty response body)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## list

> PaginatedGroupResponseList list(opts)

List groups

ViewSet for Group.  NOTE: This API endpoint is in \"tech preview\" and subject to change

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::GroupsApi.new
opts = {
  id: 56, # Integer | Filter results where id matches value
  id__in: [56], # Array<Integer> | Filter results where id is in a comma-separated list of values
  limit: 56, # Integer | Number of results to return per page.
  name: 'name_example', # String | Filter results where name matches value
  name__contains: 'name__contains_example', # String | Filter results where name contains value
  name__icontains: 'name__icontains_example', # String | Filter results where name contains value
  name__iexact: 'name__iexact_example', # String | Filter results where name matches value
  name__in: ['name__in_example'], # Array<String> | Filter results where name is in a comma-separated list of values
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List groups
  result = api_instance.list(opts)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling GroupsApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **Integer**| Filter results where id matches value | [optional] 
 **id__in** | [**Array&lt;Integer&gt;**](Integer.md)| Filter results where id is in a comma-separated list of values | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **name** | **String**| Filter results where name matches value | [optional] 
 **name__contains** | **String**| Filter results where name contains value | [optional] 
 **name__icontains** | **String**| Filter results where name contains value | [optional] 
 **name__iexact** | **String**| Filter results where name matches value | [optional] 
 **name__in** | [**Array&lt;String&gt;**](String.md)| Filter results where name is in a comma-separated list of values | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedGroupResponseList**](PaginatedGroupResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## partial_update

> GroupResponse partial_update(auth_group_href, patched_group)

Update a group

ViewSet for Group.  NOTE: This API endpoint is in \"tech preview\" and subject to change

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::GroupsApi.new
auth_group_href = 'auth_group_href_example' # String | 
patched_group = PulpcoreClient::PatchedGroup.new # PatchedGroup | 

begin
  #Update a group
  result = api_instance.partial_update(auth_group_href, patched_group)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling GroupsApi->partial_update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **auth_group_href** | **String**|  | 
 **patched_group** | [**PatchedGroup**](PatchedGroup.md)|  | 

### Return type

[**GroupResponse**](GroupResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## read

> GroupResponse read(auth_group_href, opts)

Inspect a group

ViewSet for Group.  NOTE: This API endpoint is in \"tech preview\" and subject to change

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::GroupsApi.new
auth_group_href = 'auth_group_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect a group
  result = api_instance.read(auth_group_href, opts)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling GroupsApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **auth_group_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**GroupResponse**](GroupResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update

> GroupResponse update(auth_group_href, group)

Update a group

ViewSet for Group.  NOTE: This API endpoint is in \"tech preview\" and subject to change

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::GroupsApi.new
auth_group_href = 'auth_group_href_example' # String | 
group = PulpcoreClient::Group.new # Group | 

begin
  #Update a group
  result = api_instance.update(auth_group_href, group)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling GroupsApi->update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **auth_group_href** | **String**|  | 
 **group** | [**Group**](Group.md)|  | 

### Return type

[**GroupResponse**](GroupResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json

