# PulpcoreClient::PublicationsApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**list**](PublicationsApi.md#list) | **GET** /pulp/api/v3/publications/ | List publications



## list

> PaginatedPublicationResponseList list(opts)

List publications

A customized named ModelViewSet that knows how to register itself with the Pulp API router.  This viewset is discoverable by its name. \"Normal\" Django Models and Master/Detail models are supported by the ``register_with`` method.  Attributes:     lookup_field (str): The name of the field by which an object should be looked up, in         addition to any parent lookups if this ViewSet is nested. Defaults to 'pk'     endpoint_name (str): The name of the final path segment that should identify the ViewSet's         collection endpoint.     nest_prefix (str): Optional prefix under which this ViewSet should be nested. This must         correspond to the \"parent_prefix\" of a router with rest_framework_nested.NestedMixin.         None indicates this ViewSet should not be nested.     parent_lookup_kwargs (dict): Optional mapping of key names that would appear in self.kwargs         to django model filter expressions that can be used with the corresponding value from         self.kwargs, used only by a nested ViewSet to filter based on the parent object's         identity.     schema (DefaultSchema): The schema class to use by default in a viewset.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::PublicationsApi.new
opts = {
  content: 'content_example', # String | Content Unit referenced by HREF
  content__in: 'content__in_example', # String | Content Unit referenced by HREF
  limit: 56, # Integer | Number of results to return per page.
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  pulp_created: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | ISO 8601 formatted dates are supported
  pulp_created__gt: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_created is greater than value
  pulp_created__gte: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_created is greater than or equal to value
  pulp_created__lt: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_created is less than value
  pulp_created__lte: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_created is less than or equal to value
  pulp_created__range: [DateTime.parse('2013-10-20T19:20:30+01:00')], # Array<DateTime> | Filter results where pulp_created is between two comma separated values
  repository_version: 'repository_version_example', # String | Repository Version referenced by HREF
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List publications
  result = api_instance.list(opts)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling PublicationsApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **content** | **String**| Content Unit referenced by HREF | [optional] 
 **content__in** | **String**| Content Unit referenced by HREF | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **pulp_created** | **DateTime**| ISO 8601 formatted dates are supported | [optional] 
 **pulp_created__gt** | **DateTime**| Filter results where pulp_created is greater than value | [optional] 
 **pulp_created__gte** | **DateTime**| Filter results where pulp_created is greater than or equal to value | [optional] 
 **pulp_created__lt** | **DateTime**| Filter results where pulp_created is less than value | [optional] 
 **pulp_created__lte** | **DateTime**| Filter results where pulp_created is less than or equal to value | [optional] 
 **pulp_created__range** | [**Array&lt;DateTime&gt;**](DateTime.md)| Filter results where pulp_created is between two comma separated values | [optional] 
 **repository_version** | [**String**](.md)| Repository Version referenced by HREF | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedPublicationResponseList**](PaginatedPublicationResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

