# PulpcoreClient::WorkersApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**list**](WorkersApi.md#list) | **GET** /pulp/api/v3/workers/ | List workers
[**read**](WorkersApi.md#read) | **GET** {worker_href} | Inspect a worker



## list

> PaginatedWorkerResponseList list(opts)

List workers

A customized named ModelViewSet that knows how to register itself with the Pulp API router.  This viewset is discoverable by its name. \"Normal\" Django Models and Master/Detail models are supported by the ``register_with`` method.  Attributes:     lookup_field (str): The name of the field by which an object should be looked up, in         addition to any parent lookups if this ViewSet is nested. Defaults to 'pk'     endpoint_name (str): The name of the final path segment that should identify the ViewSet's         collection endpoint.     nest_prefix (str): Optional prefix under which this ViewSet should be nested. This must         correspond to the \"parent_prefix\" of a router with rest_framework_nested.NestedMixin.         None indicates this ViewSet should not be nested.     parent_lookup_kwargs (dict): Optional mapping of key names that would appear in self.kwargs         to django model filter expressions that can be used with the corresponding value from         self.kwargs, used only by a nested ViewSet to filter based on the parent object's         identity.     schema (DefaultSchema): The schema class to use by default in a viewset.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::WorkersApi.new
opts = {
  last_heartbeat: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | ISO 8601 formatted dates are supported
  last_heartbeat__gt: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where last_heartbeat is greater than value
  last_heartbeat__gte: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where last_heartbeat is greater than or equal to value
  last_heartbeat__lt: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where last_heartbeat is less than value
  last_heartbeat__lte: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where last_heartbeat is less than or equal to value
  last_heartbeat__range: [DateTime.parse('2013-10-20T19:20:30+01:00')], # Array<DateTime> | Filter results where last_heartbeat is between two comma separated values
  limit: 56, # Integer | Number of results to return per page.
  missing: true, # Boolean | 
  name: 'name_example', # String | 
  name__contains: 'name__contains_example', # String | Filter results where name contains value
  name__icontains: 'name__icontains_example', # String | Filter results where name contains value
  name__in: ['name__in_example'], # Array<String> | Filter results where name is in a comma-separated list of values
  name__startswith: 'name__startswith_example', # String | Filter results where name starts with value
  offset: 56, # Integer | The initial index from which to return the results.
  online: true, # Boolean | 
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List workers
  result = api_instance.list(opts)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling WorkersApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **last_heartbeat** | **DateTime**| ISO 8601 formatted dates are supported | [optional] 
 **last_heartbeat__gt** | **DateTime**| Filter results where last_heartbeat is greater than value | [optional] 
 **last_heartbeat__gte** | **DateTime**| Filter results where last_heartbeat is greater than or equal to value | [optional] 
 **last_heartbeat__lt** | **DateTime**| Filter results where last_heartbeat is less than value | [optional] 
 **last_heartbeat__lte** | **DateTime**| Filter results where last_heartbeat is less than or equal to value | [optional] 
 **last_heartbeat__range** | [**Array&lt;DateTime&gt;**](DateTime.md)| Filter results where last_heartbeat is between two comma separated values | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **missing** | **Boolean**|  | [optional] 
 **name** | **String**|  | [optional] 
 **name__contains** | **String**| Filter results where name contains value | [optional] 
 **name__icontains** | **String**| Filter results where name contains value | [optional] 
 **name__in** | [**Array&lt;String&gt;**](String.md)| Filter results where name is in a comma-separated list of values | [optional] 
 **name__startswith** | **String**| Filter results where name starts with value | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **online** | **Boolean**|  | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedWorkerResponseList**](PaginatedWorkerResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> WorkerResponse read(worker_href, opts)

Inspect a worker

A customized named ModelViewSet that knows how to register itself with the Pulp API router.  This viewset is discoverable by its name. \"Normal\" Django Models and Master/Detail models are supported by the ``register_with`` method.  Attributes:     lookup_field (str): The name of the field by which an object should be looked up, in         addition to any parent lookups if this ViewSet is nested. Defaults to 'pk'     endpoint_name (str): The name of the final path segment that should identify the ViewSet's         collection endpoint.     nest_prefix (str): Optional prefix under which this ViewSet should be nested. This must         correspond to the \"parent_prefix\" of a router with rest_framework_nested.NestedMixin.         None indicates this ViewSet should not be nested.     parent_lookup_kwargs (dict): Optional mapping of key names that would appear in self.kwargs         to django model filter expressions that can be used with the corresponding value from         self.kwargs, used only by a nested ViewSet to filter based on the parent object's         identity.     schema (DefaultSchema): The schema class to use by default in a viewset.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::WorkersApi.new
worker_href = 'worker_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect a worker
  result = api_instance.read(worker_href, opts)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling WorkersApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **worker_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**WorkerResponse**](WorkerResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

